/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * xdhseqr.h
 *
 * Code generation for function 'xdhseqr'
 *
 */

#ifndef XDHSEQR_H
#define XDHSEQR_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern int eml_dlahqr(emxArray_real_T *h, emxArray_real_T *z);

#endif

/* End of code generation (xdhseqr.h) */
